@@ -1,7 +1,8 @@
 "bestset.noise" <-
 function(m = 100, n = 40)
 {
-require(leaps)
+leaps.out <- try(require(leaps), silent=TRUE)
+if ((is.logical(leaps.out)==TRUE)&(leaps.out==TRUE)){
     y <- rnorm(m)
     xx <- matrix(rnorm(m * n), ncol = n)
 dimnames(xx)<-list(NULL, paste("V",1:n,sep=""))
@@ -10,4 +11,8 @@ dimnames(xx)<-list(NULL, paste("V",1:n,sep=""))
     u1 <- lm(y ~ xx[,best3])
     print(summary(u1, corr = FALSE))
     invisible(u1)
+    }
+    else {
+    print("Error: package leaps is not installed properly")
+}
 }
